#!/usr/bin/env python3
"""
Legacy setup.py for backward compatibility.
The package is now configured using pyproject.toml.
"""

from setuptools import setup

# For backward compatibility, we keep a minimal setup.py
# The actual configuration is in pyproject.toml
setup()